| Title: | 'RStudio' Addin for Network Analysis and Visualization |
|---|---|
| Description: | 'RStudio' addin which provides a GUI to visualize and analyse networks. After finishing a session, the code to produce the plot is inserted in the current script. Alternatively, the function SNAhelperGadget() can be used directly from the console. Additional addins include the Netreader() for reading network files, Netbuilder() to create small networks via point and click, and the Componentlayouter() to layout networks with many components manually. |
| Authors: | David Schoch [aut, cre] (ORCID: <https://orcid.org/0000-0003-2952-4812>) |
| Maintainer: | David Schoch <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.4.2 |
| Built: | 2026-05-21 09:20:35 UTC |
| Source: | https://github.com/schochastics/snahelper |
Componentlayouter is an RStudio-Addin that facilitates layouting networks with several components.
ComponentlayouterAddin()ComponentlayouterAddin()
To run the addin, highlight an igraph-object in your current script and select Componentlayouter from the Addins-menu within RStudio.
Componentlayouter returns the layout as xy coordinates.
Netbuilder is an RStudio-Addin that allows you to create small networks with point and click.
NetbuilderAddin()NetbuilderAddin()
To run the addin, select Netbuilder from the Addins-menu within RStudio.
Netbuilder returns the created network as igraph object.
Netreader is an RStudio-Addin that allows you to read network files. So far, only plaintext files are supported (e.g. csv,tsv,...).
NetreaderAddin()NetreaderAddin()
To run the addin, select Netreader from the Addins-menu within RStudio.
Netreader returns the created network as igraph object.
SNAhelper is a RStudio-Addin that provides a graphical interface for network analysis and visualization.
SNAhelperGadget(graph) SNAhelperAddin()SNAhelperGadget(graph) SNAhelperAddin()
graph |
An igraph object to visualize |
To run the addin, highlight an igraph-object in your current script and select SNAhelper from the Addins-menu within RStudio. After terminating the addin, a character string containing the code for visualization is inserted in your current script. Alternatively you can run it with SNAhelperGadget(graph) from the console.
SNAhelper returns a character vector with code.
if (interactive()) { graph <- igraph::sample_gnp(100,0.2) SNAhelperGadget(graph) }if (interactive()) { graph <- igraph::sample_gnp(100,0.2) SNAhelperGadget(graph) }